cc.Class({
    "extends": cc.Component,

    properties: {
        timeTopBorder: { "default": 0.1, type: cc.Float },
        timeRightBorder: { "default": 0.1, type: cc.Float },
        timeBottomBorder: { "default": 0.1, type: cc.Float },
        timeLeftBorder: { "default": 0.1, type: cc.Float },
        startTop: true,
        enableOnLoad: false,
        effectParent: cc.Node
    },

    // use this for initialization
    onLoad: function onLoad() {
        this.particle = this.node.getComponent(cc.ParticleSystem);

        if (this.enableOnLoad) {
            this.enableParticleSystem();
        } else {
            this.disableParticleSystem();
        }
        this.instance = this;
    },

    enableParticleSystem: function enableParticleSystem() {
        console.log("enableParticleSystem in child class");
        this.particle.enabled = true;
        var instance = this;

        if (this.startTop) {
            this.node.setPosition(-(this.effectParent.width / 2) * this.effectParent.scaleX, this.effectParent.height * this.effectParent.scaleY);
        } else {
            this.node.setPosition(this.effectParent.width / 2 * this.effectParent.scaleX, 0);
        }

        var actionSequence = [];
        var moveRight = function moveRight(e) {
            if (instance.startTop) {
                var move = cc.moveBy(instance.timeTopBorder, instance.effectParent.width * instance.effectParent.scaleX, 0);
                return move;
            } else {
                var move = cc.moveBy(instance.timeBottomBorder, -(instance.effectParent.width * instance.effectParent.scaleX), 0);
                return move;
            }
        };
        var moveDown = function moveDown(e) {
            if (instance.startTop) {
                var move = cc.moveBy(instance.timeRightBorder, 0, -(instance.effectParent.height * instance.effectParent.scaleY));
                return move;
            } else {
                var move = cc.moveBy(instance.timeLeftBorder, 0, instance.effectParent.height * instance.effectParent.scaleY);
                return move;
            }
        };
        var moveLeft = function moveLeft(e) {
            if (instance.startTop) {
                var move = cc.moveBy(instance.timeBottomBorder, -(instance.effectParent.width * instance.effectParent.scaleX), 0);
                return move;
            } else {
                var move = cc.moveBy(instance.timeTopBorder, instance.effectParent.width * instance.effectParent.scaleX, 0);
                return move;
            }
        };
        var moveUp = function moveUp(e) {
            if (instance.startTop) {
                var move = cc.moveBy(instance.timeLeftBorder, 0, instance.effectParent.height * instance.effectParent.scaleY);
                return move;
            } else {
                var move = cc.moveBy(instance.timeRightBorder, 0, -(instance.effectParent.height * instance.effectParent.scaleY));
                return move;
            }
        };

        actionSequence.push(moveRight());
        actionSequence.push(moveDown());
        actionSequence.push(moveLeft());
        actionSequence.push(moveUp());
        var sequence = cc.sequence(actionSequence);
        sequence.repeatForever();

        this.node.runAction(sequence);
        this.particle.resetSystem();
    },

    disableParticleSystem: function disableParticleSystem() {
        this.particle.enabled = false;
    }

});